@@ -1,7 +1,7 @@
 package App::TableDataUtils;
 
-our $DATE = '2015-09-12'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2015-09-13'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -9,19 +9,20 @@ use warnings;
 
 our %SPEC;
 
-$SPEC{gen_hash} = {
+$SPEC{gen_rand_hash} = {
     v => 1.1,
-    summary => 'Generate hash',
+    summary => 'Generate hash with random keys/values',
     args => {
         num_keys => {
             summary => 'Number of keys',
             schema => ['int*', min=>0],
             default => 10,
             cmdline_aliases => {n=>{}},
+            pos => 0,
         },
     },
 };
-sub gen_hash {
+sub gen_rand_hash {
     my %args = @_;
 
     my $hash = {};
@@ -37,19 +38,20 @@ sub gen_hash {
     [200, "OK", $hash];
 }
 
-$SPEC{gen_aos} = {
+$SPEC{gen_rand_aos} = {
     v => 1.1,
-    summary => 'Generate array of scalars',
+    summary => 'Generate array of scalars with random values',
     args => {
         num_elems => {
             summary => 'Number of elements',
             schema => ['int*', min=>0],
             default => 10,
             cmdline_aliases => {n=>{}},
+            pos => 0,
         },
     },
 };
-sub gen_aos {
+sub gen_rand_aos {
     my %args = @_;
 
     my $aos = [];
@@ -60,25 +62,27 @@ sub gen_aos {
     [200, "OK", $aos];
 }
 
-$SPEC{gen_aoaos} = {
+$SPEC{gen_rand_aoaos} = {
     v => 1.1,
-    summary => 'Generate array of (array of scalars)',
+    summary => 'Generate array of (array of scalars) with random values',
     args => {
         num_rows => {
             summary => 'Number of rows',
             schema => ['int*', min=>0],
             default => 10,
             cmdline_aliases => {r=>{}},
+            pos => 0,
         },
         num_columns => {
             summary => 'Number of columns',
             schema => ['int*', min=>0, max=>255],
             default => 3,
             cmdline_aliases => {c=>{}},
+            pos => 1,
         },
     },
 };
-sub gen_aoaos {
+sub gen_rand_aoaos {
     my %args = @_;
 
     my $aoaos = [];
@@ -93,32 +97,34 @@ sub gen_aoaos {
     [200, "OK", $aoaos];
 }
 
-$SPEC{gen_aohos} = {
+$SPEC{gen_rand_aohos} = {
     v => 1.1,
-    summary => 'Generate array of (hash of scalars)',
+    summary => 'Generate array of (hash of scalars) with random values',
     args => {
         num_rows => {
             summary => 'Number of rows',
             schema => ['int*', min=>0],
             default => 10,
             cmdline_aliases => {r=>{}},
+            pos => 0,
         },
         num_columns => {
             summary => 'Number of columns',
             schema => ['int*', min=>0, max=>255],
             default => 3,
             cmdline_aliases => {c=>{}},
+            pos => 1,
         },
     },
 };
-sub gen_aohos {
+sub gen_rand_aohos {
     my %args = @_;
 
     my $aohos = [];
 
     my @columns;
     {
-        my $gen_hash_res = gen_hash(num_keys => $args{num_columns});
+        my $gen_hash_res = gen_rand_hash(num_keys => $args{num_columns});
         @columns = keys %{ $gen_hash_res->[2] };
     }
 
@@ -147,7 +153,7 @@ App::TableDataUtils - Routines related to table data
 
 =head1 VERSION
 
-This document describes version 0.02 of App::TableDataUtils (from Perl distribution App-TableDataUtils), released on 2015-09-12.
+This document describes version 0.03 of App::TableDataUtils (from Perl distribution App-TableDataUtils), released on 2015-09-13.
 
 =head1 DESCRIPTION
 
@@ -155,16 +161,18 @@ This distribution includes a few utility scripts related to table data.
 
 =over
 
-=item * L<gen-table-data>
+=item * L<gen-rand-table>
 
 =back
 
+The main CLI, L<tabledata>, is currently split into its own distribution.
+
 =head1 FUNCTIONS
 
 
-=head2 gen_aoaos(%args) -> [status, msg, result, meta]
+=head2 gen_rand_aoaos(%args) -> [status, msg, result, meta]
 
-Generate array of (array of scalars).
+Generate array of (array of scalars) with random values.
 
 Arguments ('*' denotes required arguments):
 
@@ -192,9 +200,9 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 gen_aohos(%args) -> [status, msg, result, meta]
+=head2 gen_rand_aohos(%args) -> [status, msg, result, meta]
 
-Generate array of (hash of scalars).
+Generate array of (hash of scalars) with random values.
 
 Arguments ('*' denotes required arguments):
 
@@ -222,9 +230,9 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 gen_aos(%args) -> [status, msg, result, meta]
+=head2 gen_rand_aos(%args) -> [status, msg, result, meta]
 
-Generate array of scalars.
+Generate array of scalars with random values.
 
 Arguments ('*' denotes required arguments):
 
@@ -248,9 +256,9 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 gen_hash(%args) -> [status, msg, result, meta]
+=head2 gen_rand_hash(%args) -> [status, msg, result, meta]
 
-Generate hash.
+Generate hash with random keys/values.
 
 Arguments ('*' denotes required arguments):
 
